==> nocc-1.9.1.tbz: www/nocc/lang/ksh.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ksh.php 2400 2011-02-24 10:59:24Z siebrand $
 */
/** Colognian (Ripoarisch)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Purodha
 */

$lang_locale = 'en_US.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Mer bruche ne Metmaacher-Name för et Aanmelde, ävver do eß kenne';
$err_passwd_empty = 'Mer bruche e Passwoot för et Aanmelde, ävver et eß kei doh';
$alt_delete = 'Schmißiß de ußjesoohte <i lang="en">e-mails</i> fott';
$alt_delete_one = 'Schmiiß di <i lang="en">e-mail</i>  fott';
$alt_new_msg = 'Neu <i lang="en">e-mails</i>';
$alt_reply = 'Aan der Vescheker aantwoote';
$alt_reply_all = 'An Alle antwoote';
$alt_forward = 'Wiggerjävve';
$alt_next = 'Nächs';
$alt_prev = 'Vörijje';
$title_next_page = 'Nächs Sigk';
$title_prev_page = 'Vörijje Sigk';
$title_next_msg = 'Nächs Nohreesch';
$title_prev_msg = 'Vörijje Nohreesch';
$html_theme_label = 'Jeschtalldong:';
$html_welcome = 'Welkumme bei %1$s';
$html_login = 'Enlogge';
$html_user_label = 'Metmaacher:';
$html_passwd_label = 'Paßwoot:';
$html_submit = 'Lohß Jonn!';
$html_help = 'Hölp';
$html_server_label = 'ẞööver:';
$html_wrong = 'Dä Name udder dat Paßwoot sin verkeeht';
$html_retry = 'Norrens!';
$html_remember = 'Aanjabe faßhallde';
$html_lang_label = 'Shprooch:';
$html_msgperpage_label = 'Aanzahl Nohresschte op ein Sigk:';
$html_preferences = 'Aanjabe';
$html_full_name_label = 'Dä kumplätte Nam:';
$html_email_address_label = 'De Adräß för de <i lang="en">e-mail</i>:';
$html_bccself = 'Scheck mer heimlesch en Koppih aan ming eije <i lang="en">e-mail</i>-Adräß';
$html_hide_addresses = 'Adräße verschteische';
$html_outlook_quoting = 'Ziteere em sellve Shtil wi „<i lang="en">Microsoft Outlook</i>“';
$html_reply_to = 'Antwoote aan';
$html_use_signature = '„Ongerschreff“ automattesch dronger seze';
$html_signature = 'De „Ongerschreff“';
$html_signature_label = '„Ongeschreff“:';
$html_reply_leadin_label = 'Der Aanfang för en Antwoot:';
$html_prefs_updated = 'Neu Aanjabe faßjehallte';
$html_manage_folders_link = 'Verzeischneße met <code lang="en">IMAP</code> verwallde';
$html_manage_filters_link = 'Feltere för de <i lang="en">e-mail</i> verwallde';
$html_use_graphical_smilies = 'Belldsche för Laachjeseeschter (un esu) nämme';
$html_sent_folder_label = 'Donn de eruß jeschek Nohreschte en e beschtemmp Verzeischnes koppeere:';
$html_trash_folder_label = 'Donn de fottjeschmeße Nohreschte en e beschtemmp Verzeischnes koppeere:';
$html_colored_quotes = 'En Bunt zitteere';
$html_display_struct = 'Text met beshtemmpte eijnfache Fommaateerunge als <i lang="en">html</i> aanzeije';
$html_send_html_mail = 'Donn Nohreschte em <code lang="en">HTML</code> Fommaat eruß schehke';
$html_folders = 'Verzeischneße';
$html_folders_create_failed = 'Dat Verzeischneß kunnt mer nit aanlääje!';
$html_folders_sub_failed = 'Mer kunnte kei Abbonnemong fö dat Verzeischneß aanlääje!';
$html_folders_unsub_failed = 'Mer kunnte dat Abbonnemong fö dat Verzeischneß nit ophüüre!';
$html_folders_rename_failed = 'Mer kunnte dat Verzeischneß nit ömbenänne!';
$html_folders_updated = 'De Verzeischneße sen op dä neußte Standt jebraat';
$html_folder_subscribe = 'Abbonnemong enreeschte';
$html_folder_rename = 'Ömbenänne';
$html_folder_create = 'Neu Verzeijschneß aanlääje mem Naame';
$html_folder_remove = 'Abonnemang afbeschtelle vun';
$html_folder_delete = 'Fottschmiiße';
$html_folder_to = 'op';
$html_filter_remove = 'Fott schmiiße';
$html_filter_body = 'Dä Täx vun dä <i lang="en">e-mail</i>';
$html_filter_subject = 'Woh drövver di <i lang="en">e-mail</i> es';
$html_filter_to = 'Wä di <i lang="en">e-mail</i> kritt';
$html_filter_cc = 'Wä en Kopih kritt';
$html_filter_from = 'Dä Affsender';
$html_filter_change_tip = 'Öm ene Fellter ze ändere, donn eijfach drövver schriive.';
$html_reapply_filters = 'Alle Feltere norr_ens aanwende';
$html_filter_contains = 'deiht enthallde';
$html_filter_name = 'Däm Fellter singe Nahme';
$html_filter_action = 'Däm Fellter sing Aufjab';
$html_filter_moveto = 'Ömtrecke noh';
$html_select_one = '--Donn eine ußsöhke--';
$html_and = 'un';
$html_new_msg_in = 'Neu Nohreeschte en';
$html_or = 'udder';
$html_move = 'Wuangersch hen donn';
$html_copy = 'Koppeere';
$html_messages_to = 'Donn de makeete Nohreeschte noh';
$html_gotopage = 'Jangk op de Sigg';
$html_gotofolder = 'Jangk noh dämm Verzeijschnes';
$html_other_folders = 'Leß met de Verzeijschneße';
$html_page = 'Sigg';
$html_of = 'vun';
$html_view_header = 'Kopp_Reije zeije';
$html_remove_header = 'Kopp_Reije vershteijshe';
$html_inbox = 'Ennjejange <i lang="en">e-mail</i>';
$html_new_msg = 'Schriive';
$html_reply = 'Antwoote';
$html_reply_short = 'Re:';
$html_reply_all = 'Antwoote aan alle';
$html_forward = 'Wigger jevve';
$html_forward_short = 'Fwd:';
$html_forward_info = 'De wigger jejovve Nohressch jeiht als ene Aanhang met he dä <i lang="en">e-mail</i> eruß.';
$html_delete = 'Schmiiß fott';
$html_new = 'Neu';
$html_mark = 'Fottschmiiße';
$html_att_label = 'Aanhang:';
$html_atts_label = 'Aanhäng:';
$html_unknown = '[weße mer nit]';
$html_part_x = 'Deil %s';
$html_attach = 'Draanhänge';
$html_attach_forget = 'Do moß Ding Datei aanjehange han, ih dat De di Nohreesch verschecke kanns.';
$html_attach_delete = 'Fottschmiiße, wat makeet es';
$html_attach_none = 'Do moß ald en Datei för draanzehänge ußsöhke!';
$html_sort_by = 'Zoteere noh';
$html_sort = 'Zoteere';
$html_from = 'Vun';
$html_from_label = 'Vum:';
$html_subject = 'Övver';
$html_subject_label = 'Övver:';
$html_date = 'Dattum';
$html_date_label = 'Dattum:';
$html_sent_label = 'Verschecker:';
$html_wrote = 'hät jeschrevve';
$html_size = 'Ömfang';
$html_totalsize = 'Ömfang zosamme jenumme';
$html_kb = 'K';
$html_mb = 'M';
$html_gb = 'G';
$html_bytes = '<i lang="en">Bytes</i>';
$html_filename = 'Dä Datei iere Name';
$html_to = 'Aan';
$html_to_label = 'Aan:';
$html_cc = 'Koppih öffentlesch aan';
$html_cc_label = 'Kopii aan:';
$html_bcc_label = 'Koppih heimlesch aan:';
$html_nosubject = 'Nix jesaat';
$html_send = 'eruß schehke';
$html_cancel = 'Ophüüre';
$html_no_mail = 'Nix Neues es aanjekumme.';
$html_logout = 'Ußlogge';
$html_msg = 'Nohreesch';
$html_msgs = 'Nohreeschte';
$html_configuration = 'Hee dä ẞööver es nit joot opjesaz woode!';
$html_priority = 'Weeschteschkeit';
$html_priority_label = 'Weschteschkeit:';
$html_lowest = 'Janz winnisch';
$html_low = 'Winnisch';
$html_normal = 'Nommaal';
$html_high = 'Mieh';
$html_highest = 'Janz weschtesch';
$html_flagged = 'Makeet';
$html_spam = 'SPAM';
$html_spam_warning = 'Di Nohreesch es als SPAM enjestohf woode.';
$html_receipt = 'En Beschtätejung för et Lesse verlange';
$html_select = 'Ußwahl';
$html_select_all = 'De Ußwahl erömdriehe';
$html_select_contacts = 'Kumtaktlück ußwähle';
$html_loading_image = 'Ben a Beld aam Laade';
$html_send_confirmed = 'Ding Nohreesch wood zom Ußlivere aanjenumme';
$html_no_sendaction = 'Kein Akßjuhn aanjejovve. De künnts et ens me JavaSkrep Ennschallde versöhke.';
$html_error_occurred = 'Ene Fähler es opjetrodde';
$html_prefs_file_error = 'Mer kunnte de Datei met de Enshtellunge nit för zem erin Schriive opmaache.';
$html_wrap = 'De Aanzahl Zeijshe, noh dänne de Reije en Nohreeschte för em Verscheke längstens ömbroche wääde:';
$html_wrap_none = 'Jaa nit ömbräsche';
$html_usenet_separator = 'Donn däm <i lang="en">usenet</i> sing „<code>-- \n</code>“ vör de „Ongerschreffte“ erin';
$html_mark_as = 'Makeere als';
$html_read = 'jelässe';
$html_unread = 'onjelässe';
$html_encoding_label = 'De Kodeerung för dä Zeijschesaz:';
$html_add = 'Dobei donn';
$html_contacts = '%1$s Kumtakte';
$html_modify = 'Ändere';
$html_back = 'Retuur';
$html_contact_add = 'Donn ene Kumtak dobei';
$html_contact_mod = 'Donn ene Kumtak ändere';
$html_contact_first = 'Vörname';
$html_contact_last = 'Nohnam';
$html_contact_nick = 'Speznam';
$html_contact_mail = 'Addräß för de <i lang="en">e-mail</i>';
$html_contact_list = '%1$s sing Kumtak_Leß';
$html_contact_del = 'fun de Kumtak_Leß';
$html_contact_count = '%1$d Kumtakte';
$html_contact_err1 = 'Et sin nit mieh wi %1$d Kumtake müjjelesch';
$html_contact_err2 = 'Do kann keine neuje Kumtak dobei donn';
$html_contact_err3 = 'Do häs nit dat Rääsch för aan de Kumtak_Leß draan ze jonn';
$html_contact_none = 'Mer han keine Kumtak jefonge.';
$html_del_msg = 'Donn de ußjesoohte Nohreeschte fottschmiiße?';
$html_down_mail = 'Erunger laade';
$original_msg = '-- Ojinaal Nohreesch --';
$to_empty = 'Wä di <i lang="en">e-mail</i> krijje sull, moß aanjejovve sin!';
$html_images_warning = 'Om Desch un Dinge Kompjutor nit en Jevaare ze bränge, dom_mer de Belder vun ußerhallef nit aanzeije.';
$html_images_display = 'Bellder zeije';
$html_smtp_error_no_conn = 'Kann kein Verbendung övver <code lang="en">smtp</code> krijje';
$html_smtp_error_unexpected = 'Dat es en Antwoot vum <code lang="en">smtp</code>-ẞööver, woh met nit drop jevaß wohre:';
$lang_could_not_connect = 'Kunnt kein Verbendung met däm ẞööver opnämme';
$lang_invalid_msg_num = 'Dat es en kappodde Nummer för en Nohreesch';
$html_file_upload_attack = 'Mer kunnte de huhjelaade Datei nit fenge — müjjelesch, dat he Eine versooht hät jeet ze kräcke, udder söns ene Dreß jeloufe es';
$html_invalid_email_address = 'Dat es en onjöltijje Addräß fö de <i lang="en">e-mail</i>';
$html_invalid_msg_per_page = 'Dat es en onjöltijje Zahl fö de Nohreeschte op jeede Sigg';
$html_invalid_wrap_msg = 'Dat es en onjöltijje Zahl fö de Zeijsche för de Reije ze ömbräsche';
$html_seperate_msg_win = 'Maach de Nohreeschte en enem extra Finster op';
$html_err_file_contacts = 'Kunnt de Datei met de Kumtakte nicht för erin ze schriive opmaache.';
$html_session_file_error = 'Mer kunnte de Datei met dä Date för Ding Sezung nit för erin ze Schriive opmaache.';
$html_login_not_allowed = 'Do bes enjelogg, ävver darfs domet hee di Verbendung nit bruche.';
$lang_err_send_delay = 'Do moß zwesche zweij <i lang="en">e-mails</i> ze&nbsp;verschecke winnischßdenß %1$d&nbsp;Sekunde waade.';
$html_search = 'Söhke';

==> nocc-1.9.3.tbz: www/nocc/lang/ksh.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ksh.php 2523 2011-12-03 11:41:12Z siebrand $
 */
/** Colognian (Ripoarisch)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Purodha
 */

$lang_locale = 'en_US.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Mer bruche ne Metmaacher-Name för et Aanmelde, ävver do eß kenne';
$err_passwd_empty = 'Mer bruche e Passwoot för et Aanmelde, ävver et eß kei doh';
$alt_delete = 'Schmißiß de ußjesoohte <i lang="en">e-mails</i> fott';
$alt_delete_one = 'Schmiiß di <i lang="en">e-mail</i>  fott';
$alt_new_msg = 'Neu <i lang="en">e-mails</i>';
$alt_reply = 'Aan der Vescheker aantwoote';
$alt_reply_all = 'An Alle antwoote';
$alt_forward = 'Wiggerjävve';
$alt_next = 'Nächs';
$alt_prev = 'Vörijje';
$title_next_page = 'Nächs Sigk';
$title_prev_page = 'Vörijje Sigk';
$title_next_msg = 'Nächs Nohreesch';
$title_prev_msg = 'Vörijje Nohreesch';
$html_theme_label = 'Jeschtalldong:';
$html_welcome = 'Welkumme bei %1$s';
$html_login = 'Enlogge';
$html_user_label = 'Metmaacher:';
$html_passwd_label = 'Paßwoot:';
$html_submit = 'Lohß Jonn!';
$html_help = 'Hölp';
$html_server_label = 'ẞööver:';
$html_wrong = 'Dä Name udder dat Paßwoot sin verkeeht';
$html_retry = 'Norrens!';
$html_remember = 'Aanjabe faßhallde';
$html_lang_label = 'Shprooch:';
$html_msgperpage_label = 'Aanzahl Nohresschte op ein Sigk:';
$html_preferences = 'Aanjabe';
$html_full_name_label = 'Dä kumplätte Nam:';
$html_email_address_label = 'De Adräß för de <i lang="en">e-mail</i>:';
$html_bccself = 'Scheck mer heimlesch en Koppih aan ming eije <i lang="en">e-mail</i>-Adräß';
$html_hide_addresses = 'Adräße verschteische';
$html_outlook_quoting = 'Ziteere em sellve Shtil wi „<i lang="en">Microsoft Outlook</i>“';
$html_reply_to = 'Antwoote aan';
$html_reply_to_label = 'Antwoot aan:';
$html_use_signature = '„Ongerschreff“ automattesch dronger seze';
$html_signature = 'De „Ongerschreff“';
$html_signature_label = '„Ongeschreff“:';
$html_reply_leadin_label = 'Der Aanfang för en Antwoot:';
$html_prefs_updated = 'Neu Aanjabe faßjehallte';
$html_manage_folders_link = 'Verzeischneße met <code lang="en">IMAP</code> verwallde';
$html_manage_filters_link = 'Feltere för de <i lang="en">e-mail</i> verwallde';
$html_use_graphical_smilies = 'Belldsche för Laachjeseeschter (un esu) nämme';
$html_sent_folder_label = 'Donn de eruß jeschek Nohreschte en e beschtemmp Verzeischnes koppeere:';
$html_trash_folder_label = 'Donn de fottjeschmeße Nohreschte en e beschtemmp Verzeischnes koppeere:';
$html_colored_quotes = 'En Bunt zitteere';
$html_display_struct = 'Text met beshtemmpte eijnfache Fommaateerunge als <i lang="en">html</i> aanzeije';
$html_send_html_mail = 'Donn Nohreschte em <code lang="en">HTML</code> Fommaat eruß schehke';
$html_folders = 'Verzeischneße';
$html_folders_create_failed = 'Dat Verzeischneß kunnt mer nit aanlääje!';
$html_folders_sub_failed = 'Mer kunnte kei Abbonnemong fö dat Verzeischneß aanlääje!';
$html_folders_unsub_failed = 'Mer kunnte dat Abbonnemong fö dat Verzeischneß nit ophüüre!';
$html_folders_rename_failed = 'Mer kunnte dat Verzeischneß nit ömbenänne!';
$html_folders_updated = 'De Verzeischneße sen op dä neußte Standt jebraat';
$html_folder_subscribe = 'Abbonnemong enreeschte';
$html_folder_rename = 'Ömbenänne';
$html_folder_create = 'Neu Verzeijschneß aanlääje mem Naame';
$html_folder_remove = 'Abonnemang afbeschtelle vun';
$html_folder_delete = 'Fottschmiiße';
$html_folder_to = 'op';
$html_filter_remove = 'Fott schmiiße';
$html_filter_body = 'Dä Täx vun dä <i lang="en">e-mail</i>';
$html_filter_subject = 'Woh drövver di <i lang="en">e-mail</i> es';
$html_filter_to = 'Wä di <i lang="en">e-mail</i> kritt';
$html_filter_cc = 'Wä en Kopih kritt';
$html_filter_from = 'Dä Affsender';
$html_filter_change_tip = 'Öm ene Fellter ze ändere, donn eijfach drövver schriive.';
$html_reapply_filters = 'Alle Feltere norr_ens aanwende';
$html_filter_contains = 'deiht enthallde';
$html_filter_name = 'Däm Fellter singe Nahme';
$html_filter_action = 'Däm Fellter sing Aufjab';
$html_filter_moveto = 'Ömtrecke noh';
$html_select_one = '--Donn eine ußsöhke--';
$html_and = 'un';
$html_new_msg_in = 'Neu Nohreeschte en';
$html_or = 'udder';
$html_move = 'Wuangersch hen donn';
$html_copy = 'Koppeere';
$html_messages_to = 'Donn de makeete Nohreeschte noh';
$html_gotopage = 'Jangk op de Sigg';
$html_gotofolder = 'Jangk noh dämm Verzeijschnes';
$html_other_folders = 'Leß met de Verzeijschneße';
$html_page = 'Sigg';
$html_of = 'vun';
$html_view_header = 'Kopp_Reije zeije';
$html_remove_header = 'Kopp_Reije vershteijshe';
$html_inbox = 'Ennjejange <i lang="en">e-mail</i>';
$html_new_msg = 'Schriive';
$html_reply = 'Antwoote';
$html_reply_short = 'Re:';
$html_reply_all = 'Antwoote aan alle';
$html_forward = 'Wigger jevve';
$html_forward_short = 'Fwd:';
$html_forward_info = 'De wigger jejovve Nohressch jeiht als ene Aanhang met he dä <i lang="en">e-mail</i> eruß.';
$html_delete = 'Schmiiß fott';
$html_new = 'Neu';
$html_mark = 'Fottschmiiße';
$html_att_label = 'Aanhang:';
$html_atts_label = 'Aanhäng:';
$html_unknown = '[weße mer nit]';
$html_part_x = 'Deil %s';
$html_attach = 'Draanhänge';
$html_attach_forget = 'Do moß Ding Datei aanjehange han, ih dat De di Nohreesch verschecke kanns.';
$html_attach_delete = 'Fottschmiiße, wat makeet es';
$html_attach_none = 'Do moß ald en Datei för draanzehänge ußsöhke!';
$html_sort_by = 'Zoteere noh';
$html_sort = 'Zoteere';
$html_from = 'Vun';
$html_from_label = 'Vum:';
$html_subject = 'Övver';
$html_subject_label = 'Övver:';
$html_date = 'Dattum';
$html_date_label = 'Dattum:';
$html_sent_label = 'Verschecker:';
$html_wrote = 'hät jeschrevve';
$html_size = 'Ömfang';
$html_totalsize = 'Ömfang zosamme jenumme';
$html_kb = 'K';
$html_mb = 'M';
$html_gb = 'G';
$html_bytes = '<i lang="en">Bytes</i>';
$html_filename = 'Dä Datei iere Name';
$html_to = 'Aan';
$html_to_label = 'Aan:';
$html_cc = 'Koppih öffentlesch aan';
$html_cc_label = 'Kopii aan:';
$html_bcc_label = 'Koppih heimlesch aan:';
$html_nosubject = 'Nix jesaat';
$html_send = 'eruß schehke';
$html_cancel = 'Ophüüre';
$html_no_mail = 'Nix Neues es aanjekumme.';
$html_logout = 'Ußlogge';
$html_msg = 'Nohreesch';
$html_msgs = 'Nohreeschte';
$html_configuration = 'Hee dä ẞööver es nit joot opjesaz woode!';
$html_priority = 'Weeschteschkeit';
$html_priority_label = 'Weschteschkeit:';
$html_lowest = 'Janz winnisch';
$html_low = 'Winnisch';
$html_normal = 'Nommaal';
$html_high = 'Mieh';
$html_highest = 'Janz weschtesch';
$html_flagged = 'Makeet';
$html_spam = 'SPAM';
$html_spam_warning = 'Di Nohreesch es als SPAM enjestohf woode.';
$html_receipt = 'En Beschtätejung för et Lesse verlange';
$html_select = 'Ußwahl';
$html_select_all = 'De Ußwahl erömdriehe';
$html_select_contacts = 'Kumtaktlück ußwähle';
$html_loading_image = 'Ben e Beld aam Laade';
$html_send_confirmed = 'Ding Nohreesch wood zom Ußlivere aanjenumme';
$html_no_sendaction = 'Kein Akßjuhn aanjejovve. De künnts et ens me JavaSkrep Ennschallde versöhke.';
$html_error_occurred = 'Ene Fähler es opjetrodde';
$html_prefs_file_error = 'Mer kunnte de Datei met de Enshtellunge nit för zem erin Schriive opmaache.';
$html_wrap = 'De Aanzahl Zeijshe, noh dänne de Reije en Nohreeschte för em Verscheke längstens ömbroche wääde:';
$html_wrap_none = 'Jaa nit ömbräsche';
$html_usenet_separator = 'Donn däm <i lang="en">usenet</i> sing „<code>-- \n</code>“ vör de „Ongerschreffte“ erin';
$html_mark_as = 'Makeere als';
$html_read = 'jelässe';
$html_unread = 'onjelässe';
$html_encoding_label = 'De Kodeerung för dä Zeijschesaz:';
$html_add = 'Dobei donn';
$html_contacts = '%1$s Kumtakte';
$html_modify = 'Ändere';
$html_back = 'Retuur';
$html_contact_add = 'Donn ene Kumtak dobei';
$html_contact_mod = 'Donn ene Kumtak ändere';
$html_contact_first = 'Vörname';
$html_contact_last = 'Nohnam';
$html_contact_nick = 'Speznam';
$html_contact_mail = 'Addräß för de <i lang="en">e-mail</i>';
$html_contact_list = '%1$s sing Kumtak_Leß';
$html_contact_del = 'fun de Kumtak_Leß';
$html_contact_count = '%1$d Kumtakte';
$html_contact_err1 = 'Et sin nit mieh wi %1$d Kumtake müjjelesch';
$html_contact_err2 = 'Do kann keine neuje Kumtak dobei donn';
$html_contact_err3 = 'Do häs nit dat Rääsch för aan de Kumtak_Leß draan ze jonn';
$html_contact_none = 'Mer han keine Kumtak jefonge.';
$html_del_msg = 'Donn de ußjesoohte Nohreeschte fottschmiiße?';
$html_down_mail = 'Eronger laade';
$original_msg = '-- Ojinaal Nohreesch --';
$to_empty = 'Wä di <i lang="en">e-mail</i> krijje sull, moß aanjejovve sin!';
$html_images_warning = 'Om Desch un Dinge Kompjutor nit en Jevaare ze bränge, dom_mer de Belder vun ußerhallef nit aanzeije.';
$html_images_display = 'Bellder zeije';
$html_smtp_error_no_conn = 'Kann kein Verbendung övver <code lang="en">smtp</code> krijje';
$html_smtp_error_unexpected = 'Dat es en Antwoot vum <code lang="en">smtp</code>-ẞööver, woh met nit drop jevaß wohre:';
$lang_could_not_connect = 'Kunnt kein Verbendung met däm ẞööver opnämme';
$lang_invalid_msg_num = 'Dat es en kappodde Nummer för en Nohreesch';
$html_file_upload_attack = 'Mer kunnte de huhjelaade Datei nit fenge — müjjelesch, dat he Eine versooht hät jeet ze kräcke, udder söns ene Dreß jeloufe es';
$html_invalid_email_address = 'Dat es en onjöltijje Addräß fö de <i lang="en">e-mail</i>';
$html_invalid_msg_per_page = 'Dat es en onjöltijje Zahl fö de Nohreeschte op jeede Sigg';
$html_invalid_wrap_msg = 'Dat es en onjöltijje Zahl fö de Zeijsche för de Reije ze ömbräsche';
$html_seperate_msg_win = 'Maach de Nohreeschte en enem extra Finster op';
$html_err_file_contacts = 'Kunnt de Datei met de Kumtakte nicht för erin ze schriive opmaache.';
$html_session_file_error = 'Mer kunnte de Datei met dä Date för Ding Sezung nit för erin ze Schriive opmaache.';
$html_login_not_allowed = 'Do bes enjelogg, ävver darfs domet hee di Verbendung nit bruche.';
$lang_err_send_delay = 'Do moß zwesche zweij <i lang="en">e-mails</i> ze&nbsp;verschecke winnischßdenß %1$d&nbsp;Sekunde waade.';
$html_search = 'Söhke';
